import { IconButton } from '@suid/material';
import { Component, createSignal } from 'solid-js';
import { Geolocation } from '@awesome-cordova-plugins/geolocation';

import NoteIcon from '@suid/icons-material/Note';

import style from './Note.module.css';
import WptEditDialog from '../wpt/WptEditDialog';
import { Coordinate } from 'ol/coordinate';

interface Props {}

const Note: Component<Props> = (props) => {
  const [open, setOpen] = createSignal<boolean>(false);
  const [coordinate, setCoordinate] = createSignal<Coordinate>();

  const openWptEditDialogWithCurrentLocation = async () => {
    const position = await Geolocation.getCurrentPosition();
    setCoordinate([position.coords.longitude, position.coords.latitude]);
    setOpen(true);
  };

  return (
    <>
      <div
        class={
          window.Capacitor.platform === 'web'
            ? style.control_web
            : style.control
        }
      >
        {' '}
        <IconButton onClick={openWptEditDialogWithCurrentLocation}>
          <NoteIcon />
        </IconButton>
      </div>
      <WptEditDialog
        open={open}
        closeHandler={() => setOpen(false)}
        coordinate={coordinate}
      />
    </>
  );
};

export default Note;
